Item class

Representa um item (produto ou serviço) no pedido.

É obrigatório ter pelo menos 1 item no pedido. O valor do produto deve ser informado em centavos (R$ 10,00 = 1000 centavos).

Exemplo:

final item = Item(
  description: 'Produto exemplo',
  quantity: 2,
  price: 1000, // R$ 10,00 em centavos
);

Constructors

Item({required String description, required int quantity, required int price})
Item.fromMap(Map<String, dynamic> map)
factory

Properties

description → String
Descrição do produto ou serviço.
final
hashCode → int
The hash code for this object.
no setterinherited
price → int
Preço unitário do item em centavos.
final
quantity → int
Quantidade do item no pedido.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited