PaymentCheckRequest class

Constructors

PaymentCheckRequest({required String handle, required String? orderNSU, required String? transactionNSU, required String? slug})
PaymentCheckRequest.fromMap(Map<String, dynamic> map)
factory

Properties

handle → String
final
hashCode → int
The hash code for this object.
no setterinherited
orderNSU → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slug → String?
final
transactionNSU → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited