PaymentCheckResponse class

Resposta da verificação de status de pagamento.

Contém informações sobre o sucesso da consulta, se o pagamento foi realizado, valores e método de captura utilizado.

Exemplo de resposta:

{
  "success": true,
  "paid": true,
  "amount": 1500,
  "paid_amount": 1510,
  "installments": 1,
  "capture_method": "pix"
}

Constructors

PaymentCheckResponse({required bool success, required bool paid, required int amount, required int paidAmount, required int installments, required String captureMethod})
PaymentCheckResponse.fromMap(Map<String, dynamic> map)
factory

Properties

amount → int
Valor original do pedido em centavos.
final
captureMethod → String
Método de captura utilizado.
final
hashCode → int
The hash code for this object.
no setterinherited
installments → int
Número de parcelas do pagamento.
final
Indica se o pagamento foi realizado.
final
paidAmount → int
Valor efetivamente pago em centavos.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
Indica se a consulta foi bem-sucedida.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited