CheckoutService class

Constructors

CheckoutService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkPayment(PaymentCheckRequest paymentCheck) Future<PaymentCheckResponse>
Verifica o status de um pagamento.
createCheckout(Payload payload) Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited