Customer class

Representa os dados do comprador no checkout.

Esta classe é opcional no payload. Se você já tiver o nome, e-mail e telefone do comprador, pode enviá-los para agilizar o processo. Isso facilita o checkout, pois as informações já estarão preenchidas.

Exemplo:

final customer = Customer(
  name: 'João Silva',
  email: 'joao@email.com',
  phoneNumber: '+5511999887766',
);

Constructors

Customer({required String name, required String email, required String phoneNumber})
const
Customer.fromMap(Map<String, dynamic> map)
factory

Properties

email String
E-mail do comprador.
final
hashCode int
The hash code for this object.
no setterinherited
name String
Nome completo do comprador.
final
phoneNumber String
Número de telefone do comprador (com código do país).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited